from django.db import models
from django.db.models import JSONField

class Vehicle(models.Model):
    car_number = models.CharField(max_length=20, unique=True)
    transport_mode = models.CharField(max_length=20, choices=[('Truck', 'Truck'), ('Van', 'Van')])
    capacity = models.CharField(max_length=50)

    def __str__(self):
        return self.car_number

from django.db import models
from django.contrib.postgres.fields import JSONField
from django.contrib.postgres.fields import JSONField

from django.db import models 

class Driver(models.Model):
    name = models.CharField(max_length=100)
    telephone = models.CharField(max_length=20)
    driver_id = models.CharField(max_length=20, unique=True, null=True, blank=True)
    licensed = models.BooleanField(default=True)
    vehicle_assigned = models.ForeignKey(Vehicle, on_delete=models.SET_NULL, null=True, blank=True)
    rating = models.FloatField(default=0)   
    comments = models.JSONField(default=list)   

    def __str__(self):
        return self.name

    def update_rating(self, new_rating):
        """Update driver's rating by recalculating the average rating."""
        ratings_count = DriverRating.objects.filter(driver=self).count()
        if ratings_count == 0:
            self.rating = new_rating
        else:
            total_ratings = sum([rating.rating for rating in DriverRating.objects.filter(driver=self)])
            self.rating = (total_ratings + new_rating) / (ratings_count + 1)
        self.save()


    
class DriverRating(models.Model):
    driver = models.ForeignKey(Driver, on_delete=models.CASCADE, related_name='ratings')
    rating = models.IntegerField()
    comments = models.TextField(null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return f"Rating {self.rating} for {self.driver.name}"



